@@ -4,9 +4,9 @@
 # Author          : Ulrich Pfeifer
 # Created On      : Mon Mar 25 09:59:37 1996
 # Last Modified By: Ulrich Pfeifer
-# Last Modified On: Fri May 29 15:26:52 1998
+# Last Modified On: Fri Jun 12 10:09:26 1998
 # Language        : Perl
-# Update Count    : 34
+# Update Count    : 35
 # Status          : Unknown, Use with caution!
 # 
 # (C) Copyright 1996, Universitt Dortmund, all rights reserved.
@@ -28,13 +28,13 @@ use vars qw(@ISA);
 sub next {
     my $self = shift;
     my $fh = $self->{Fh};
-    my ($Date: Fri, 29 May 1998 15:30:18 +0200 $Hour, @Databases, $Queries);
+    my ($date, $Hour, @Databases, $Queries);
     unless (@Databases) {
       *S = $fh;
     LINE: while (1) {
         return undef if (eof(S));
         my $line = <S>;
-        $Date: Fri, 29 May 1998 15:30:18 +0200 $line,0,14);
+        $date = substr($line,0,14);
         ($Hour) = ($line =~ /\s(\d\d):\d\d/);
         next LINE if length($line) < 24;
         my ($pid, $host, $request) = split ' ', substr($line,24);
@@ -52,7 +52,7 @@ sub next {
     }
     Logfile::Base::Record->new(Database   => shift @Databases,
                                Queries    => $Queries,
-                               Date       => $Date,
+                               Date       => $date,
                                Hour       => $Hour,
                               );
 }
